import { Client } from 'graphql-ws';
import { ConnectorPriceElementComponentType as ConnectorPriceElementComponentType_2 } from '../../generated/graphql';
import { ConnectorPriceProductSubscriptionType as ConnectorPriceProductSubscriptionType_2 } from '../../generated/graphql';
import { ConnectorPriceProductType as ConnectorPriceProductType_2 } from '../../generated/graphql';
import { ConnectorPriceRestrictionsOverstayTimeUnit as ConnectorPriceRestrictionsOverstayTimeUnit_2 } from '../../generated/graphql';
import { ConnectorPriceRestrictionsReservationType as ConnectorPriceRestrictionsReservationType_2 } from '../../generated/graphql';
import { CurrencyUnit as CurrencyUnit_2 } from '../../generated/graphql';
import { DayOfWeek as DayOfWeek_2 } from '../../generated/graphql';
import { default as default_2 } from 'graphql-tag';
import { EasingOptions } from 'mapbox-gl';
import { ExpressionSpecification } from 'mapbox-gl';
import { Feature } from 'geojson';
import { FeatureCollection } from 'geojson';
import { GetLegPropertiesConnectorInput as GetLegPropertiesConnectorInput_2 } from './types';
import { GetLegPropertiesEvseInput as GetLegPropertiesEvseInput_2 } from './types';
import { LayerSpecification } from 'mapbox-gl';
import { LngLat } from 'mapbox-gl';
import { Map as Map_2 } from 'mapbox-gl';
import { PaddingOptions } from 'mapbox-gl';
import { Point } from 'geojson';
import { Position } from 'geojson';
import { SourceSpecification } from 'mapbox-gl';

export declare interface AmenitiesFilters {
    hotel?: boolean;
    shopping?: boolean;
    bathroom?: boolean;
    supermarket?: boolean;
    playground?: boolean;
    pharmacy?: boolean;
    coffee?: boolean;
    museum?: boolean;
    park?: boolean;
    restaurant?: boolean;
}

export declare const appendFilterParams: (params: URLSearchParams, filterName: string, filterValues: PowerGroupsFilters | ConnectorsFilters | AmenitiesFilters) => void;

export declare const buildIconImageExpression: (markers: Marker[]) => ExpressionSpecification;

export declare const buildOffsetExpression: (markers: Marker[]) => ExpressionSpecification;

export declare const calculateVat: (price?: number, vat?: number) => number;

export declare type CategorizedSections = {
    nonDriving: number[][][];
    ferry: number[][][];
    driving: number[][][];
};

export declare type ChargeDurationInput = {
    connectorPower: number;
    vehicle: {
        battery: {
            usable_kwh: number;
        };
        connectors: Array<{
            standard: ConnectorType;
            power?: Maybe<number>;
        }>;
        adapters?: Array<{
            standard: ConnectorType;
            power?: Maybe<number>;
        }>;
    };
    standard: ConnectorType | null;
    usableBattery?: number;
};

declare const ChargerStatus: {
    readonly BUSY: "busy";
    readonly ERROR: "error";
    readonly FREE: "free";
    readonly UNKNOWN: "unknown";
};

declare type ChargerStatus = (typeof ChargerStatus)[keyof typeof ChargerStatus];

export declare type ColorValueRgb = `rgb(${number},${number},${number})`;

export declare type ColorValueRgba = `rgba(${number},${number},${number},${number})`;

export declare type ConfigHeaders = {
    'x-app-id': string;
    'x-client-id': string;
} & Headers_2;

declare type ConnectorFragment = {
    __typename?: 'Connector';
    id?: string | null;
    standard?: ConnectorType | null;
    power?: number | null;
    prices?: Array<{
        __typename?: 'ConnectorPrice';
        partner?: string | null;
        partner_id: string;
        product: {
            __typename?: 'ConnectorPriceProduct';
            type: ConnectorPriceProductType;
            description: string;
            subscription_type: ConnectorPriceProductSubscriptionType;
            subscription_fee_excl_vat: number;
            currency: CurrencyUnit;
        };
        elements: Array<{
            __typename?: 'ConnectorPriceElement';
            components: Array<{
                __typename?: 'ConnectorPriceElementComponent';
                type: ConnectorPriceElementComponentType;
                price_excl_vat: number;
                vat: number;
            }>;
            restrictions?: {
                __typename?: 'ConnectorPriceElementRestrictions';
                start_time?: string | null;
                end_time?: string | null;
                start_date?: string | null;
                end_date?: string | null;
                minimum_kwh?: number | null;
                maximum_kwh?: number | null;
                minimum_power?: number | null;
                maximum_power?: number | null;
                minimum_current?: number | null;
                maximum_current?: number | null;
                minimum_price?: number | null;
                maximum_price?: number | null;
                minimum_duration?: number | null;
                maximum_duration?: number | null;
                day_of_week?: Array<DayOfWeek> | null;
                reservation?: ConnectorPriceRestrictionsReservationType | null;
                overstay_battery_percentage?: {
                    __typename?: 'ConnectorPriceRestrictionsOverstayBatteryPercentage';
                    minimum?: number | null;
                    maximum?: number | null;
                    unit?: ConnectorPriceRestrictionsOverstayTimeUnit | null;
                } | null;
                overstay_time?: {
                    __typename?: 'ConnectorPriceRestrictionsOverstayTime';
                    minimum?: number | null;
                    maximum?: number | null;
                    unit?: ConnectorPriceRestrictionsOverstayTimeUnit | null;
                } | null;
                emsp_contract_date?: {
                    __typename?: 'ConnectorPriceRestrictionsEmspContractDate';
                    name?: string | null;
                    from?: string | null;
                    to?: string | null;
                } | null;
            } | null;
        }>;
    }> | null;
};

declare type ConnectorPriceElementComponentFragment = {
    __typename?: 'ConnectorPriceElementComponent';
    type: ConnectorPriceElementComponentType;
    price_excl_vat: number;
    vat: number;
};

declare const ConnectorPriceElementComponentType: {
    readonly ENERGY: "energy";
    readonly FLAT: "flat";
    readonly PARKING_TIME: "parking_time";
    readonly TIME: "time";
};

declare type ConnectorPriceElementComponentType = (typeof ConnectorPriceElementComponentType)[keyof typeof ConnectorPriceElementComponentType];

declare type ConnectorPriceElementFragment = {
    __typename?: 'ConnectorPriceElement';
    components: Array<{
        __typename?: 'ConnectorPriceElementComponent';
        type: ConnectorPriceElementComponentType;
        price_excl_vat: number;
        vat: number;
    }>;
    restrictions?: {
        __typename?: 'ConnectorPriceElementRestrictions';
        start_time?: string | null;
        end_time?: string | null;
        start_date?: string | null;
        end_date?: string | null;
        minimum_kwh?: number | null;
        maximum_kwh?: number | null;
        minimum_power?: number | null;
        maximum_power?: number | null;
        minimum_current?: number | null;
        maximum_current?: number | null;
        minimum_price?: number | null;
        maximum_price?: number | null;
        minimum_duration?: number | null;
        maximum_duration?: number | null;
        day_of_week?: Array<DayOfWeek> | null;
        reservation?: ConnectorPriceRestrictionsReservationType | null;
        overstay_battery_percentage?: {
            __typename?: 'ConnectorPriceRestrictionsOverstayBatteryPercentage';
            minimum?: number | null;
            maximum?: number | null;
            unit?: ConnectorPriceRestrictionsOverstayTimeUnit | null;
        } | null;
        overstay_time?: {
            __typename?: 'ConnectorPriceRestrictionsOverstayTime';
            minimum?: number | null;
            maximum?: number | null;
            unit?: ConnectorPriceRestrictionsOverstayTimeUnit | null;
        } | null;
        emsp_contract_date?: {
            __typename?: 'ConnectorPriceRestrictionsEmspContractDate';
            name?: string | null;
            from?: string | null;
            to?: string | null;
        } | null;
    } | null;
};

declare type ConnectorPriceFragment = {
    __typename?: 'ConnectorPrice';
    partner?: string | null;
    partner_id: string;
    product: {
        __typename?: 'ConnectorPriceProduct';
        type: ConnectorPriceProductType;
        description: string;
        subscription_type: ConnectorPriceProductSubscriptionType;
        subscription_fee_excl_vat: number;
        currency: CurrencyUnit;
    };
    elements: Array<{
        __typename?: 'ConnectorPriceElement';
        components: Array<{
            __typename?: 'ConnectorPriceElementComponent';
            type: ConnectorPriceElementComponentType;
            price_excl_vat: number;
            vat: number;
        }>;
        restrictions?: {
            __typename?: 'ConnectorPriceElementRestrictions';
            start_time?: string | null;
            end_time?: string | null;
            start_date?: string | null;
            end_date?: string | null;
            minimum_kwh?: number | null;
            maximum_kwh?: number | null;
            minimum_power?: number | null;
            maximum_power?: number | null;
            minimum_current?: number | null;
            maximum_current?: number | null;
            minimum_price?: number | null;
            maximum_price?: number | null;
            minimum_duration?: number | null;
            maximum_duration?: number | null;
            day_of_week?: Array<DayOfWeek> | null;
            reservation?: ConnectorPriceRestrictionsReservationType | null;
            overstay_battery_percentage?: {
                __typename?: 'ConnectorPriceRestrictionsOverstayBatteryPercentage';
                minimum?: number | null;
                maximum?: number | null;
                unit?: ConnectorPriceRestrictionsOverstayTimeUnit | null;
            } | null;
            overstay_time?: {
                __typename?: 'ConnectorPriceRestrictionsOverstayTime';
                minimum?: number | null;
                maximum?: number | null;
                unit?: ConnectorPriceRestrictionsOverstayTimeUnit | null;
            } | null;
            emsp_contract_date?: {
                __typename?: 'ConnectorPriceRestrictionsEmspContractDate';
                name?: string | null;
                from?: string | null;
                to?: string | null;
            } | null;
        } | null;
    }>;
};

declare const ConnectorPriceProductSubscriptionType: {
    readonly MONTHLY: "monthly";
    readonly NOT_APPLICABLE: "not_applicable";
    readonly ONE_OFF: "one_off";
    readonly YEARLY: "yearly";
};

declare type ConnectorPriceProductSubscriptionType = (typeof ConnectorPriceProductSubscriptionType)[keyof typeof ConnectorPriceProductSubscriptionType];

declare const ConnectorPriceProductType: {
    readonly AD_HOC: "ad_hoc";
    readonly CPO_SUBSCRIPTION: "cpo_subscription";
    readonly MSP: "msp";
};

declare type ConnectorPriceProductType = (typeof ConnectorPriceProductType)[keyof typeof ConnectorPriceProductType];

declare type ConnectorPriceRestrictionsOverstayTime = {
    __typename?: 'ConnectorPriceRestrictionsOverstayTime';
    maximum?: Maybe<Scalars['Int']['output']>;
    minimum?: Maybe<Scalars['Int']['output']>;
    unit?: Maybe<ConnectorPriceRestrictionsOverstayTimeUnit>;
};

declare const ConnectorPriceRestrictionsOverstayTimeUnit: {
    readonly HOURS: "hours";
    readonly MINUTES: "minutes";
    readonly SECONDS: "seconds";
};

declare type ConnectorPriceRestrictionsOverstayTimeUnit = (typeof ConnectorPriceRestrictionsOverstayTimeUnit)[keyof typeof ConnectorPriceRestrictionsOverstayTimeUnit];

declare const ConnectorPriceRestrictionsReservationType: {
    readonly RESERVATION: "reservation";
    readonly RESERVATION_EXPIRES: "reservation_expires";
};

declare type ConnectorPriceRestrictionsReservationType = (typeof ConnectorPriceRestrictionsReservationType)[keyof typeof ConnectorPriceRestrictionsReservationType];

export declare interface ConnectorsFilters {
    IEC_62196_T1?: boolean;
    IEC_62196_T1_COMBO?: boolean;
    IEC_62196_T2?: boolean;
    IEC_62196_T2_COMBO?: boolean;
    CHADEMO?: boolean;
    TESLA_S?: boolean;
}

declare const ConnectorType: {
    readonly CHADEMO: "CHADEMO";
    readonly CHAOJI: "CHAOJI";
    readonly DOMESTIC_A: "DOMESTIC_A";
    readonly DOMESTIC_B: "DOMESTIC_B";
    readonly DOMESTIC_C: "DOMESTIC_C";
    readonly DOMESTIC_D: "DOMESTIC_D";
    readonly DOMESTIC_E: "DOMESTIC_E";
    readonly DOMESTIC_F: "DOMESTIC_F";
    readonly DOMESTIC_G: "DOMESTIC_G";
    readonly DOMESTIC_H: "DOMESTIC_H";
    readonly DOMESTIC_I: "DOMESTIC_I";
    readonly DOMESTIC_J: "DOMESTIC_J";
    readonly DOMESTIC_K: "DOMESTIC_K";
    readonly DOMESTIC_L: "DOMESTIC_L";
    readonly DOMESTIC_M: "DOMESTIC_M";
    readonly DOMESTIC_N: "DOMESTIC_N";
    readonly DOMESTIC_O: "DOMESTIC_O";
    readonly GB_T: "GB_T";
    readonly IEC_60309_2_SINGLE_16: "IEC_60309_2_single_16";
    readonly IEC_60309_2_THREE_16: "IEC_60309_2_three_16";
    readonly IEC_60309_2_THREE_32: "IEC_60309_2_three_32";
    readonly IEC_60309_2_THREE_64: "IEC_60309_2_three_64";
    readonly IEC_62196_T1: "IEC_62196_T1";
    readonly IEC_62196_T1_COMBO: "IEC_62196_T1_COMBO";
    readonly IEC_62196_T2: "IEC_62196_T2";
    readonly IEC_62196_T2_COMBO: "IEC_62196_T2_COMBO";
    readonly IEC_62196_T3A: "IEC_62196_T3A";
    readonly IEC_62196_T3C: "IEC_62196_T3C";
    readonly NEMA_5_20: "NEMA_5_20";
    readonly NEMA_6_30: "NEMA_6_30";
    readonly NEMA_6_50: "NEMA_6_50";
    readonly NEMA_10_30: "NEMA_10_30";
    readonly NEMA_10_50: "NEMA_10_50";
    readonly NEMA_14_30: "NEMA_14_30";
    readonly NEMA_14_50: "NEMA_14_50";
    readonly PANTOGRAPH_BOTTOM_UP: "PANTOGRAPH_BOTTOM_UP";
    readonly PANTOGRAPH_TOP_DOWN: "PANTOGRAPH_TOP_DOWN";
    readonly TESLA_R: "TESLA_R";
    readonly TESLA_S: "TESLA_S";
};

declare type ConnectorType = (typeof ConnectorType)[keyof typeof ConnectorType];

export declare const createSource: (feature: Feature | FeatureCollection) => SourceSpecification;

declare const CurrencyUnit: {
    readonly AED: "AED";
    readonly AFN: "AFN";
    readonly ALL: "ALL";
    readonly AMD: "AMD";
    readonly ANG: "ANG";
    readonly AOA: "AOA";
    readonly ARS: "ARS";
    readonly AUD: "AUD";
    readonly AWG: "AWG";
    readonly AZN: "AZN";
    readonly BAM: "BAM";
    readonly BBD: "BBD";
    readonly BDT: "BDT";
    readonly BGN: "BGN";
    readonly BIF: "BIF";
    readonly BMD: "BMD";
    readonly BND: "BND";
    readonly BOB: "BOB";
    readonly BRL: "BRL";
    readonly BSD: "BSD";
    readonly BWP: "BWP";
    readonly BYN: "BYN";
    readonly BZD: "BZD";
    readonly CAD: "CAD";
    readonly CDF: "CDF";
    readonly CHF: "CHF";
    readonly CLP: "CLP";
    readonly CNY: "CNY";
    readonly COP: "COP";
    readonly CRC: "CRC";
    readonly CVE: "CVE";
    readonly CZK: "CZK";
    readonly DJF: "DJF";
    readonly DKK: "DKK";
    readonly DOP: "DOP";
    readonly DZD: "DZD";
    readonly EGP: "EGP";
    readonly ETB: "ETB";
    readonly EUR: "EUR";
    readonly FJD: "FJD";
    readonly FKP: "FKP";
    readonly GBP: "GBP";
    readonly GEL: "GEL";
    readonly GIP: "GIP";
    readonly GMD: "GMD";
    readonly GNF: "GNF";
    readonly GTQ: "GTQ";
    readonly GYD: "GYD";
    readonly HKD: "HKD";
    readonly HNL: "HNL";
    readonly HTG: "HTG";
    readonly HUF: "HUF";
    readonly IDR: "IDR";
    readonly ILS: "ILS";
    readonly INR: "INR";
    readonly ISK: "ISK";
    readonly JMD: "JMD";
    readonly JPY: "JPY";
    readonly KES: "KES";
    readonly KGS: "KGS";
    readonly KHR: "KHR";
    readonly KMF: "KMF";
    readonly KRW: "KRW";
    readonly KYD: "KYD";
    readonly KZT: "KZT";
    readonly LAK: "LAK";
    readonly LBP: "LBP";
    readonly LKR: "LKR";
    readonly LRD: "LRD";
    readonly LSL: "LSL";
    readonly MAD: "MAD";
    readonly MDL: "MDL";
    readonly MGA: "MGA";
    readonly MKD: "MKD";
    readonly MMK: "MMK";
    readonly MNT: "MNT";
    readonly MOP: "MOP";
    readonly MUR: "MUR";
    readonly MVR: "MVR";
    readonly MWK: "MWK";
    readonly MXN: "MXN";
    readonly MYR: "MYR";
    readonly MZN: "MZN";
    readonly NAD: "NAD";
    readonly NGN: "NGN";
    readonly NIO: "NIO";
    readonly NOK: "NOK";
    readonly NPR: "NPR";
    readonly NZD: "NZD";
    readonly PAB: "PAB";
    readonly PEN: "PEN";
    readonly PGK: "PGK";
    readonly PHP: "PHP";
    readonly PKR: "PKR";
    readonly PLN: "PLN";
    readonly PYG: "PYG";
    readonly QAR: "QAR";
    readonly RON: "RON";
    readonly RSD: "RSD";
    readonly RUB: "RUB";
    readonly RWF: "RWF";
    readonly SAR: "SAR";
    readonly SBD: "SBD";
    readonly SCR: "SCR";
    readonly SEK: "SEK";
    readonly SGD: "SGD";
    readonly SHP: "SHP";
    readonly SLE: "SLE";
    readonly SOS: "SOS";
    readonly SRD: "SRD";
    readonly STD: "STD";
    readonly SZL: "SZL";
    readonly THB: "THB";
    readonly TJS: "TJS";
    readonly TOP: "TOP";
    readonly TRY: "TRY";
    readonly TTD: "TTD";
    readonly TWD: "TWD";
    readonly TZS: "TZS";
    readonly UAH: "UAH";
    readonly UGX: "UGX";
    readonly USD: "USD";
    readonly UYU: "UYU";
    readonly UZS: "UZS";
    readonly VND: "VND";
    readonly VUV: "VUV";
    readonly WST: "WST";
    readonly XAF: "XAF";
    readonly XCD: "XCD";
    readonly XOF: "XOF";
    readonly XPF: "XPF";
    readonly YER: "YER";
    readonly ZAR: "ZAR";
    readonly ZMW: "ZMW";
};

declare type CurrencyUnit = (typeof CurrencyUnit)[keyof typeof CurrencyUnit];

declare const DayOfWeek: {
    readonly FRIDAY: "friday";
    readonly MONDAY: "monday";
    readonly SATURDAY: "saturday";
    readonly SUNDAY: "sunday";
    readonly THURSDAY: "thursday";
    readonly TUESDAY: "tuesday";
    readonly WEDNESDAY: "wednesday";
};

declare type DayOfWeek = (typeof DayOfWeek)[keyof typeof DayOfWeek];

declare const FeatureType: {
    readonly FEATURE: "Feature";
};

declare type FeatureType = (typeof FeatureType)[keyof typeof FeatureType];

export declare class FetcherModule {
    config: FetcherModuleConfig;
    resolve: ((value: any) => void) | undefined;
    reject: ((value: unknown) => void) | undefined;
    wsClient: Client | undefined;
    url: string;
    wsUrl: string;
    constructor(config: FetcherModuleConfig);
    query<Query, Vars extends QueryVariables>(options: QueryOptions<Vars>, headers?: Record<string, string>): Promise<Query>;
    getRoute<Q extends RouteQueryInput, S extends RouteSubscriptionInput, V extends QueryVariables>(options: QueryOptions<V> & Subscription): Promise<S['route'] | Q['getRoute']>;
    private subscribe;
}

export declare type FetcherModuleConfig = {
    webSocketImpl?: unknown;
    headers: () => ConfigHeaders;
    url: string;
    wsUrl: string;
};

export declare const findBestPricing: (prices: ConnectorPriceFragment[]) => ConnectorPriceFragment;

export declare const findMarkerIndexForPower: (markers: Marker[], power: number | null | undefined) => number | "UNKNOWN";

export declare const findPowerMarkerArrayIndex: (markers: Marker[], power: number) => number;

export declare const getChargeDuration: (input: ChargeDurationInput) => number;

export declare const getChargeSessionCosts: ({ connector, duration, consumption, }: {
    connector?: Maybe<ConnectorFragment>;
    consumption: number;
    duration: number;
}) => Maybe<number>;

export declare const getDefaultProperties: (leg: RouteOverviewModuleLegInput) => Omit<TimelineItemBase, "date">;

export declare const getFormattedChargingTime: (value: number) => string;

export declare const getLayerProps: (id: MapLayerId, styling: MapboxModuleConfig["styling"]) => LayerSpecification;

declare type GetLegPropertiesConnectorInput = {
    id?: Maybe<string>;
    power?: Maybe<number>;
    standard?: Maybe<ConnectorType>;
    [x: string | number | symbol]: unknown;
};

declare type GetLegPropertiesEvseInput = {
    evse_id?: Maybe<string>;
    status?: Maybe<OcpiStatus>;
    connectors?: Maybe<Array<Maybe<GetLegPropertiesConnectorInput>>>;
    [x: string | number | symbol]: unknown;
};

declare type GetLegPropertiesStationInput = {
    id: string;
    evses?: Maybe<Array<Maybe<GetLegPropertiesEvseInput>>>;
    [x: string | number | symbol]: unknown;
};

export declare const getMarkerElement: ({ prefix, type, label }: MarkerAnnotationInput) => HTMLElement;

export declare const getNestedStationProps: <T extends GetLegPropertiesStationInput>(stations: T[], routeDetailsLegStation?: Maybe<RouteDetailsLegStation>) => {
    station: T | undefined;
    evse: Maybe<GetLegPropertiesEvseInput_2> | undefined;
    connector: Maybe<GetLegPropertiesConnectorInput_2> | undefined;
};

export declare const getPlaceName: (value: string | null | undefined) => string;

export declare const getPowerType: (power: number | null | undefined) => StationSpeedType;

export declare const getStationProperties: (stations: RouteOverviewModuleStationInput[], leg: RouteOverviewModuleLegInput) => StationProperties;

export declare const getStationSpeedType: (status: OcpiStatus | undefined | null) => ChargerStatus;

export declare const getWalkingDuration: (distance: number) => number;

declare type Headers_2 = Record<string, string>;
export { Headers_2 as Headers }

export declare type InputFeaturePoint = {
    geometry: {
        coordinates: Array<number>;
        [x: string | number | symbol]: unknown;
    };
    properties?: Maybe<{
        id?: Maybe<string>;
        name?: Maybe<string>;
        [x: string | number | symbol]: unknown;
    }>;
    [x: string | number | symbol]: unknown;
};

export declare const LAYER_IDS: readonly ["search-location-point", "isoline", "isoline-border", "polyline", "polyline-dashed", "origin", "loading-circle", "waypoint", "plan-route-line", "ferry-icon", "tile-clusters", "tile-stations", "route-stations", "alternative-station", "alternative-station-selected", "destination", "station-selected"];

export declare const layerSortOrderMap: Map<MapLayerId, string | MapLayerId | undefined>;

export declare class MapboxModule {
    map: MapboxModuleConfig['map'];
    stations: Exclude<MapboxModuleConfig['stations'], undefined>;
    isoline: MapboxModuleConfig['isoline'];
    routeDetails: MapboxModuleConfig['routeDetails'];
    styling: MapboxModuleConfig['styling'];
    animationDuration: number;
    polylinePrecision: number;
    categorizedSection: CategorizedSections;
    textTransform: MapboxModuleConfig['textTransform'];
    selectedStationId: string | undefined | null;
    selectedAlternativeStationId: string | undefined | null;
    raf: number | undefined;
    markersAnnotations: mapboxgl.Marker[];
    padding: PaddingOptions | undefined;
    tileUrl: MapboxModuleConfig['tileUrl'];
    constructor(config: MapboxModuleConfig);
    drawRouteDetails(): void;
    removeRouteDetails(): void;
    drawIsoline(): void;
    removeIsoline(): void;
    private drawPolyline;
    private drawMarkers;
    private getLegFeature;
    drawPlanRoute(features: Feature<Point>[]): void;
    removePlanRoute(): void;
    private drawWaypoints;
    private drawOrigin;
    private drawDestination;
    private get stationLegs();
    drawSearch(feature: Feature<Point>): void;
    removeSearch(): void;
    drawStationTiles(filters?: TileFilters): void;
    removeStationTiles(): void;
    setTileFilters(filters: TileFilters): void;
    private getTileUrl;
    private addMarkerAnnotation;
    private drawRouteStations;
    private drawStationMarkers;
    drawLoadingCircle(position: Position): void;
    removeLoadingCircle(): void;
    private drawAlternativeStations;
    private addLayerToMap;
    setSelectedStation(feature: Feature<Point, StationFeatureProperties> | null): void;
    setSelectedAlternativeStationId(feature: Feature<Point, StationFeatureProperties> | null): void;
    toggleAlternativeStations(): void;
    toggleLayerVisibility(id: MapLayerId): void;
    setLayerVisibility(id: MapLayerId, isVisible: boolean): void;
    private setLayoutProperty;
    private setPaintProperty;
    private centerFeatures;
    private centerPolyline;
    flyTo(options: EasingOptions): void;
    private center;
    private get legs();
    private get sections();
    removeAll(): void;
    private removeAllLayers;
    private removeAllMarkerAnnotation;
    removeLayer(id: MapLayerId): void;
    removeSource(id: string): void;
    setRouteDetails(value: MapboxModuleConfig['routeDetails']): this;
    setIsoline(value: MapboxModuleConfig['isoline']): this;
    setStations(value: MapboxModuleConfig['stations']): this;
}

export declare type MapboxModuleAlternativeStationInput = {
    id: string;
    location: {
        coordinates: Array<number>;
        [x: string | number | symbol]: unknown;
    };
    [x: string | number | symbol]: unknown;
};

export declare type MapboxModuleConfig = {
    map: Map_2;
    tileUrl?: string;
    routeDetails?: Maybe<{
        legs: Array<MapboxModuleLegInput>;
        alternative_stations?: Maybe<Array<MapboxModuleAlternativeStationInput>>;
        [x: string | number | symbol]: unknown;
    }>;
    isoline?: Maybe<{
        polygons?: Array<MapboxModulePolygonInput | null> | null;
        ferries?: Array<MapboxModuleFerryInput | null> | null;
        request_input?: MapboxModuleRequestInput | null;
        [x: string | number | symbol]: unknown;
    }>;
    stations?: Array<StationInput>;
    styling: MapboxModuleStyling;
    padding?: PaddingOptions;
    polylinePrecision?: number;
    textTransform?: (path: string) => string;
};

export declare type MapboxModuleConnectorInput = {
    id?: Maybe<string>;
    standard?: Maybe<ConnectorType>;
    power?: Maybe<number>;
    [x: string | number | symbol]: unknown;
};

export declare type MapboxModuleEvseInput = {
    evse_id?: Maybe<string>;
    status?: Maybe<OcpiStatus>;
    connectors?: Maybe<Array<Maybe<MapboxModuleConnectorInput>>>;
    [x: string | number | symbol]: unknown;
};

export declare type MapboxModuleFerryInput = {
    __typename?: 'FeatureLineString';
    geometry: {
        __typename?: 'LineString';
        coordinates: Array<Array<number> | null>;
    };
    [x: string | number | symbol]: unknown;
};

export declare type MapboxModuleLegInput = {
    name?: Maybe<string>;
    type: RouteDetailsLegType;
    origin: InputFeaturePoint;
    destination: InputFeaturePoint;
    durations: {
        total: number;
        charging: number;
        driving: number;
        stopover: number;
        ferry?: Maybe<number>;
    };
    station?: Maybe<{
        station_id: string;
        connector_id: string;
        evse_id?: Maybe<string>;
        [x: string | number | symbol]: unknown;
    }>;
    sections: Array<SectionInput>;
    [x: string | number | symbol]: unknown;
};

export declare type MapboxModulePolygonInput = {
    __typename?: 'FeatureMultiPolygon';
    type: FeatureType;
    geometry: {
        __typename?: 'MultiPolygon';
        type: MultiPolygonType;
        coordinates: Array<Array<Array<Array<number> | null> | null> | null>;
        [x: string | number | symbol]: unknown;
    };
    properties?: {
        __typename?: 'PolygonProperties';
        index?: number | null;
    } | null;
    [x: string | number | symbol]: unknown;
};

export declare type MapboxModuleRequestInput = {
    __typename?: 'IsolineRequestInput';
    polygon_count?: number | null;
    origin: {
        __typename?: 'FeaturePoint';
        type: FeatureType;
        geometry: {
            __typename?: 'Point';
            type: PointType;
            coordinates: Array<number>;
        };
        [x: string | number | symbol]: unknown;
    };
    [x: string | number | symbol]: unknown;
};

export declare type MapboxModuleStyling = {
    polyline: {
        fill: PolylineSettings;
        border: PolylineSettings;
    };
    dashedPolyline: {
        fill: PolylineSettings;
        border: PolylineSettings;
    };
    markerAnnotations: Record<MarkerAnnotationType, {
        offset: number;
    }>;
    isoline: {
        polygon: {
            fill: {
                paint: string;
            };
            border: {
                width: number;
                paint: string;
            };
        };
    };
    cluster: {
        text: {
            paint: string;
            size: number;
            offset: [number, number];
        };
    };
    markers: Marker[];
};

export declare type MapLayerId = (typeof LAYER_IDS)[number];

export declare const mapSpeedTypeToPower: (speed: StationSpeedType | null | undefined) => number;

export declare interface Marker {
    index: number;
    offset: [number, number];
    power: {
        from: number;
        to: number;
    };
    operators?: {
        ids: string[];
        name: string;
        offset: [number, number];
    }[];
    [x: string | number | symbol]: unknown;
}

export declare type MarkerAnnotationInput = {
    type: MarkerAnnotationType;
    lngLat: LngLat;
    prefix?: string;
    label: string;
};

export declare type MarkerAnnotationType = 'place' | 'station';

declare type Maybe<T> = T | null;

export declare const millisecondsToHour: (ms: number) => number;

declare const MultiPolygonType: {
    readonly MULTIPOLYGON: "MultiPolygon";
};

declare type MultiPolygonType = (typeof MultiPolygonType)[keyof typeof MultiPolygonType];

export declare const nearestPointOnPolyline: (coordinates: number[][]) => Feature<Point, {
    [key: string]: any;
    dist: number;
    index: number;
    multiFeatureIndex: number;
    location: number;
}>;

export declare type NormalizedLegInput = MapboxModuleLegInput & {
    legConnector?: Maybe<MapboxModuleConnectorInput>;
    legEvse?: Maybe<MapboxModuleEvseInput>;
    legStation?: Maybe<StationInput>;
};

declare const OcpiStatus: {
    readonly AVAILABLE: "AVAILABLE";
    readonly BLOCKED: "BLOCKED";
    readonly CHARGING: "CHARGING";
    readonly INOPERATIVE: "INOPERATIVE";
    readonly OUTOFORDER: "OUTOFORDER";
    readonly PLANNED: "PLANNED";
    readonly REMOVED: "REMOVED";
    readonly RESERVED: "RESERVED";
    readonly UNKNOWN: "UNKNOWN";
};

declare type OcpiStatus = (typeof OcpiStatus)[keyof typeof OcpiStatus];

declare const PointType: {
    readonly POINT: "Point";
};

declare type PointType = (typeof PointType)[keyof typeof PointType];

export declare type PolylineSettings = {
    paint: ColorValueRgba | ColorValueRgb;
    width: number;
};

export declare interface PowerGroupsFilters {
    turbo?: boolean;
    fast?: boolean;
    slow?: boolean;
}

export declare interface PreferencesFilters {
    matchVehicle?: boolean;
    availableOnly?: boolean;
    preferredOperator?: boolean;
    operatorIds?: string[];
}

export declare class PricingModule {
    price: PricingModuleConfig['price'];
    consumption: PricingModuleConfig['consumption'];
    duration: PricingModuleConfig['duration'];
    constructor(config: PricingModuleConfig);
    get currency(): CurrencyUnit;
    get priceElement(): ConnectorPriceElementFragment;
    get totalPrice(): number;
    getComponent(type: ConnectorPriceElementComponentType): ConnectorPriceElementComponentFragment | undefined;
    get energyPriceElement(): ConnectorPriceElementComponentFragment | undefined;
    get flatFee(): number;
    get idleFee(): {
        perMinute: number;
        overstayTime?: Maybe<ConnectorPriceRestrictionsOverstayTime>;
    };
}

export declare type PricingModuleConfig = {
    consumption: number;
    duration: number;
    price: ConnectorPriceFragment;
};

export declare type Query = ReturnType<typeof default_2> | string;

export declare type QueryOptions<Vars> = {
    query: Query;
    variables?: Vars;
    headers?: Headers_2;
};

export declare type QueryVariables = Record<string, unknown>;

declare type RouteDetailsDurations = {
    __typename?: 'RouteDetailsDurations';
    charging: Scalars['Int']['output'];
    driving: Scalars['Int']['output'];
    ferry?: Maybe<Scalars['Int']['output']>;
    stopover: Scalars['Int']['output'];
    total: Scalars['Int']['output'];
};

declare type RouteDetailsLegFeatureProperties = {
    __typename?: 'RouteDetailsLegFeatureProperties';
    air_pressure?: Maybe<Scalars['Float']['output']>;
    duration?: Maybe<Scalars['Int']['output']>;
    external_station_id?: Maybe<Scalars['ID']['output']>;
    name?: Maybe<Scalars['String']['output']>;
    occupants?: Maybe<Scalars['Int']['output']>;
    solar_irradiance?: Maybe<Scalars['Float']['output']>;
    station_id?: Maybe<Scalars['ID']['output']>;
    temperature?: Maybe<Scalars['Int']['output']>;
    total_cargo_weight?: Maybe<Scalars['Float']['output']>;
    total_occupant_weight?: Maybe<Scalars['Float']['output']>;
};

declare const RouteDetailsLegSectionType: {
    readonly DRIVING: "driving";
    readonly FERRY: "ferry";
    readonly WALKING: "walking";
};

declare type RouteDetailsLegSectionType = (typeof RouteDetailsLegSectionType)[keyof typeof RouteDetailsLegSectionType];

declare type RouteDetailsLegStation = {
    __typename?: 'RouteDetailsLegStation';
    connector_id: Scalars['ID']['output'];
    evse_id?: Maybe<Scalars['ID']['output']>;
    station_id: Scalars['ID']['output'];
};

declare const RouteDetailsLegType: {
    readonly FINAL: "final";
    readonly STATION: "station";
    readonly STATION_AMENITY: "station_amenity";
    readonly STATION_FINAL: "station_final";
    readonly STATION_VIA: "station_via";
    readonly VIA: "via";
};

declare type RouteDetailsLegType = (typeof RouteDetailsLegType)[keyof typeof RouteDetailsLegType];

declare const RouteDetailsTag: {
    readonly CROSSBORDER: "crossborder";
    readonly FERRY: "ferry";
    readonly HIGHWAY: "highway";
    readonly ROAD: "road";
    readonly TOLL: "toll";
    readonly WALKING: "walking";
};

declare type RouteDetailsTag = (typeof RouteDetailsTag)[keyof typeof RouteDetailsTag];

export declare class RouteOverviewModule {
    config: RouteOverviewModuleConfig;
    private legArrivalDate;
    private stations;
    private legs;
    timeline: TimelineItem[];
    private viaIndex;
    constructor(config: RouteOverviewModuleConfig);
    get originName(): string | undefined | null;
    get destinationName(): string | undefined | null;
    get totalCost(): number;
    getTimeline(): TimelineItem[];
    private getTimelineItemDriving;
    private getTimelineItemWalking;
    private incrementLegArrivalDate;
    private getTimelineItem;
}

export declare type RouteOverviewModuleConfig = {
    departureDate?: Date;
    legs: RouteOverviewModuleLegInput[];
    stations?: RouteOverviewModuleStationInput[];
    includeWalkingStep?: boolean;
};

declare type RouteOverviewModuleLegFeaturePointInput = {
    properties?: Maybe<RouteDetailsLegFeatureProperties>;
    geometry?: {
        coordinates?: Array<number>;
        [x: string | number | symbol]: unknown;
    };
    [x: string | number | symbol]: unknown;
};

export declare type RouteOverviewModuleLegInput = {
    name?: Maybe<string>;
    type: RouteDetailsLegType | 'origin' | 'walking_final';
    tags: RouteDetailsTag[];
    consumption: number;
    distance: number;
    range_at_origin: number;
    range_at_origin_percentage: number;
    range_at_destination: number;
    range_at_destination_percentage: number;
    range_after_charge?: Maybe<number>;
    sections: Maybe<Array<RouteOverviewModuleLegSectionInput>>;
    range_after_charge_percentage?: Maybe<number>;
    durations: {
        total: number;
        charging: number;
        driving: number;
        stopover: number;
        ferry?: Maybe<number>;
    };
    station?: Maybe<{
        station_id: string;
        connector_id: string;
        evse_id?: Maybe<string>;
        [x: string | number | symbol]: unknown;
    }>;
    origin: RouteOverviewModuleLegFeaturePointInput;
    destination: RouteOverviewModuleLegFeaturePointInput;
    [x: string | number | symbol]: unknown;
};

export declare type RouteOverviewModuleLegSectionInput = {
    distance: number;
    [x: string | number | symbol]: unknown;
};

export declare type RouteOverviewModuleStationInput = {
    __typename?: 'Station';
    id: string;
    name?: string | null;
    operator?: {
        __typename?: 'Operator';
        id?: string | null;
        name?: string | null;
    } | null;
    evses?: Maybe<Array<Maybe<StationModuleEvseInput>>>;
    [x: string | number | symbol]: unknown;
};

export declare type RouteQueryInput = {
    getRoute: {
        status: RouteStatus;
    };
};

declare const RouteStatus: {
    readonly DONE: "done";
    readonly ERROR: "error";
    readonly NOT_FOUND: "not_found";
    readonly PENDING: "pending";
    readonly PROCESSING: "processing";
};

declare type RouteStatus = (typeof RouteStatus)[keyof typeof RouteStatus];

export declare type RouteSubscriptionInput = {
    route: {
        status: RouteStatus;
    };
};

declare type Scalars = {
    ID: {
        input: string;
        output: string;
    };
    String: {
        input: string;
        output: string;
    };
    Boolean: {
        input: boolean;
        output: boolean;
    };
    Int: {
        input: number;
        output: number;
    };
    Float: {
        input: number;
        output: number;
    };
    Acknowledgement: {
        input: any;
        output: any;
    };
    DateTime: {
        input: any;
        output: any;
    };
    Email: {
        input: any;
        output: any;
    };
    JSON: {
        input: any;
        output: any;
    };
    NonEmptyString: {
        input: any;
        output: any;
    };
    PlainID: {
        input: any;
        output: any;
    };
    PlainString: {
        input: any;
        output: any;
    };
    Upload: {
        input: any;
        output: any;
    };
};

export declare type SectionInput = {
    type: RouteDetailsLegSectionType;
    polyline?: Maybe<string>;
    origin: InputFeaturePoint;
    destination: InputFeaturePoint;
    [x: string | number | symbol]: unknown;
};

export declare const sectionsReducer: (sections: SectionInput[], precision: number) => CategorizedSections;

export declare type StandardMap = Map<ConnectorType, {
    powers: Map<number, ConnectorFragment[]>;
}>;

export declare type StationFeatureProperties = {
    id: Maybe<string>;
    speed?: Maybe<StationSpeedType>;
    status: Maybe<ChargerStatus>;
};

export declare type StationInput = {
    id: string;
    name?: Maybe<string>;
    operator?: Maybe<{
        id?: Maybe<string>;
        name?: Maybe<string>;
        [x: string | number | symbol]: unknown;
    }>;
    evses?: Maybe<Array<Maybe<MapboxModuleEvseInput>>>;
    [x: string | number | symbol]: unknown;
};

export declare class StationModule {
    evses: StationModuleConfig['evses'];
    constructor(config: StationModuleConfig);
    get connectors(): Array<StationModuleConnectorInput>;
    get standards(): StandardMap;
    getConnector({ standard, power }: {
        standard: ConnectorType;
        power: number;
    }): ConnectorFragment | undefined;
    getPrice({ connector, partnerId }: {
        connector: ConnectorFragment;
        partnerId: string;
    }): {
        __typename?: "ConnectorPrice";
        partner?: string | null;
        partner_id: string;
        product: {
            __typename?: "ConnectorPriceProduct";
            type: ConnectorPriceProductType_2;
            description: string;
            subscription_type: ConnectorPriceProductSubscriptionType_2;
            subscription_fee_excl_vat: number;
            currency: CurrencyUnit_2;
        };
        elements: Array<{
            __typename?: "ConnectorPriceElement";
            components: Array<{
                __typename?: "ConnectorPriceElementComponent";
                type: ConnectorPriceElementComponentType_2;
                price_excl_vat: number;
                vat: number;
            }>;
            restrictions?: {
                __typename?: "ConnectorPriceElementRestrictions";
                start_time?: string | null;
                end_time?: string | null;
                start_date?: string | null;
                end_date?: string | null;
                minimum_kwh?: number | null;
                maximum_kwh?: number | null;
                minimum_power?: number | null;
                maximum_power?: number | null;
                minimum_current?: number | null;
                maximum_current?: number | null;
                minimum_price?: number | null;
                maximum_price?: number | null;
                minimum_duration?: number | null;
                maximum_duration?: number | null;
                day_of_week?: Array<DayOfWeek_2> | null;
                reservation?: ConnectorPriceRestrictionsReservationType_2 | null;
                overstay_battery_percentage?: {
                    __typename?: "ConnectorPriceRestrictionsOverstayBatteryPercentage";
                    minimum?: number | null;
                    maximum?: number | null;
                    unit?: ConnectorPriceRestrictionsOverstayTimeUnit_2 | null;
                } | null;
                overstay_time?: {
                    __typename?: "ConnectorPriceRestrictionsOverstayTime";
                    minimum?: number | null;
                    maximum?: number | null;
                    unit?: ConnectorPriceRestrictionsOverstayTimeUnit_2 | null;
                } | null;
                emsp_contract_date?: {
                    __typename?: "ConnectorPriceRestrictionsEmspContractDate";
                    name?: string | null;
                    from?: string | null;
                    to?: string | null;
                } | null;
            } | null;
        }>;
    } | undefined;
}

export declare type StationModuleConfig = {
    evses: Array<StationModuleEvseInput>;
};

export declare type StationModuleConnectorInput = {
    __typename?: 'Connector';
    id?: Maybe<string>;
    standard?: Maybe<ConnectorType>;
    power?: Maybe<number>;
    prices?: Maybe<Array<ConnectorPriceFragment>>;
};

export declare type StationModuleEvseInput = {
    __typename?: 'EVSE';
    evse_id?: Maybe<string>;
    connectors?: Maybe<Array<Maybe<StationModuleConnectorInput>>>;
};

export declare type StationProperties = {
    id?: Maybe<string>;
    label?: Maybe<string>;
    evse: TimelineItemStationEvse;
    operator: TimelineItemStationOperator;
    charging: TimelineItemStationCharging;
};

declare const StationSpeedType: {
    readonly FAST: "fast";
    readonly SLOW: "slow";
    readonly TURBO: "turbo";
};

declare type StationSpeedType = (typeof StationSpeedType)[keyof typeof StationSpeedType];

export declare const stringifyQuery: (query: Query) => string;

export declare type Subscription = {
    subscription: Query;
};

export declare type TileFilters = {
    preferences?: PreferencesFilters;
    powerGroups?: PowerGroupsFilters;
    connectors?: ConnectorsFilters;
    amenities?: AmenitiesFilters;
};

export declare const tileServerQueryParams: (filters: TileFilters) => string;

export declare type TimelineItem = TimelineItemOrigin | TimelineItemVia | TimelineItemStation | TimelineItemDestination | TimelineItemWalkingDestination | TimelineItemDriving | TimelineItemWalking;

export declare type TimelineItemBase = {
    label?: string | null;
    date: Date;
    coordinates?: Array<number>;
    consumption?: Maybe<number>;
    distance?: Maybe<number>;
    range_at_origin?: Maybe<number>;
    range_at_origin_percentage?: Maybe<number>;
    range_at_destination?: Maybe<number>;
    range_at_destination_percentage?: Maybe<number>;
    range_after_charge?: Maybe<number>;
    range_after_charge_percentage?: Maybe<number>;
    durations?: Maybe<RouteDetailsDurations>;
    properties: Maybe<Omit<RouteDetailsLegFeatureProperties, 'name'>>;
};

export declare type TimelineItemDestination = {
    type: 'destination';
} & TimelineItemBase;

export declare type TimelineItemDriving = {
    type: 'driving';
    duration: number;
    distance: number;
    tags: RouteDetailsTag[];
};

export declare type TimelineItemOrigin = {
    type: 'origin';
} & TimelineItemBase;

export declare type TimelineItemStation = {
    type: 'station';
} & StationProperties & TimelineItemBase;

export declare type TimelineItemStationCharging = {
    id?: Maybe<string>;
    cost?: Maybe<number>;
    power?: Maybe<number>;
    standard?: Maybe<ConnectorType>;
};

export declare type TimelineItemStationEvse = {
    id?: Maybe<string>;
    status?: Maybe<OcpiStatus>;
};

export declare type TimelineItemStationOperator = {
    name?: string | null;
    id?: string | null;
};

export declare type TimelineItemVia = {
    type: 'via';
    index: number;
} & TimelineItemBase;

export declare type TimelineItemWalking = {
    type: 'walking';
    duration: number;
    distance: number;
};

export declare type TimelineItemWalkingDestination = {
    type: 'walking-destination';
} & TimelineItemBase;

export declare type WebsocketData<T> = {
    id: string;
    type: string;
    payload: {
        data: T;
    };
};

export { }
